@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from ocp_resources.constants import TIMEOUT_4MINUTES
+
 from ocp_resources.resource import Resource
 
 
@@ -12,33 +12,20 @@ class ClusterRole(Resource):
 
     def __init__(
         self,
-        name=None,
+        name,
         client=None,
         api_groups=None,
         permissions_to_resources=None,
         verbs=None,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
-        super().__init__(
-            client=client,
-            name=name,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
-        )
+        super().__init__(client=client, name=name, teardown=teardown)
         self.api_groups = api_groups
         self.permissions_to_resources = permissions_to_resources
         self.verbs = verbs
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         rules = {}
         if self.api_groups:
             rules["apiGroups"] = self.api_groups
