@@ -1,6 +1,6 @@
 import json
 
-from ocp_resources.resource import NamespacedResource, Resource
+from ocp_resources.resource import NamespacedResource
 
 
 class Template(NamespacedResource):
@@ -15,7 +15,7 @@ class Template(NamespacedResource):
 
     class Workload:
         DESKTOP = "desktop"
-        HIGHPERFORMANCE = "highperformance"
+        HIGH_PERFORMANCE = "highperformance"
         SERVER = "server"
 
     class Flavor:
@@ -34,11 +34,6 @@ class Template(NamespacedResource):
             f"{NamespacedResource.ApiGroup.TEMPLATE_KUBEVIRT_IO}/provider-url"
         )
 
-    class VMAnnotations:
-        OS = f"{Resource.ApiGroup.VM_KUBEVIRT_IO}/os"
-        FLAVOR = f"{Resource.ApiGroup.VM_KUBEVIRT_IO}/flavor"
-        WORKLOAD = f"{Resource.ApiGroup.VM_KUBEVIRT_IO}/workload"
-
     def process(self, client=None, **kwargs):
         client = client or self.client
         instance_dict = self.instance.to_dict()
